==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The tag key.
 * @property value The tag value.
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs(
    public val key: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs> {
    override fun toJava():
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs].
 */
@PulumiTagMarker
public class
ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder
internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The tag key.
     */
    @JvmName("fwgvqtctahrnovqj")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The tag value.
     */
    @JvmName("yffgixnamxrgwqdy")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The tag key.
     */
    @JvmName("fanxamlycyqvwxlh")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The tag value.
     */
    @JvmName("lccwnidmucjkmgcd")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build():
        ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs(
            key = key,
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/inputs/ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.inputs

import com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The tag key.
 * @property value The tag value.
 */
public data class ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs(
    public val key: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs> {
    override fun toJava(): com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs =
        com.pulumi.aws.macie2.inputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs].
 */
@PulumiTagMarker
public class
ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgsBuilder
internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The tag key.
     */
    @JvmName("sjaokxeqnnbokvhr")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The tag value.
     */
    @JvmName("wrrdioenijncdeue")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The tag key.
     */
    @JvmName("xjfbckgbmnsbsewd")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The tag value.
     */
    @JvmName("hrkitpisktrmepci")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs =
        ClassificationJobS3JobDefinitionBucketCriteriaIncludesAndTagCriterionTagValueArgs(
            key = key,
            `value` = `value`,
        )
}
